@@ -1,3 +1,14 @@
+"""
+    @file:              patient_data_query_strategy.py
+    @Author:            Maxence Larose
+
+    @Creation Date:     10/2021
+    @Last modification: 01/2022
+
+    @Description:       This file contains the class PatientDataQueryStrategies that enumerates the available categories
+                        for the queries a user can make to obtain a patient's data.
+"""
+
 import enum
 from typing import NamedTuple, Callable
 
@@ -10,24 +21,24 @@ class PatientDataQueryStrategy(NamedTuple):
     factory: Callable
 
 
-class PatientDataQueryStrategies(PatientDataQueryStrategy, enum.Enum):
+class PatientDataQueryStrategies(enum.Enum):
 
-    DEFAULT: PatientDataQueryStrategy = PatientDataQueryStrategy(
+    DEFAULT = PatientDataQueryStrategy(
         name="Default",
         factory=DefaultPatientDataFactory
     )
 
-    SEGMENTATION: PatientDataQueryStrategy = PatientDataQueryStrategy(
+    SEGMENTATION = PatientDataQueryStrategy(
         name="Segmentation",
         factory=SegmentationPatientDataFactory
     )
 
-    SERIES_DESCRIPTION: PatientDataQueryStrategy = PatientDataQueryStrategy(
+    SERIES_DESCRIPTION = PatientDataQueryStrategy(
         name="Series description",
         factory=SeriesDescriptionPatientDataFactory
     )
 
-    SEGMENTATION_AND_SERIES_DESCRIPTION: PatientDataQueryStrategy = PatientDataQueryStrategy(
+    SEGMENTATION_AND_SERIES_DESCRIPTION = PatientDataQueryStrategy(
         name="Segmentation and series description",
         factory=SegmentationAndSeriesDescriptionPatientDataFactory
     )
